@@ -106,10 +106,12 @@ class hexagon_grid:
     def __init__(self,
                  data, 
                  spacing,
+                 hexagon_dis = True,
                  area_threshold:float = None
                  ):
         self.data = data
         self.spacing = spacing
+        self.hexagon_dis = hexagon_dis
         self.area_threshold = area_threshold
         if isinstance(data, str):
             gdf = gpd.read_file(self.data)
@@ -182,28 +184,31 @@ class hexagon_grid:
                                 gpd.overlay(gdf.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
-        if self.area_threshold == None:
-            area_thres = (spacing*spacing)*0.33
-            hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
-            df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
-            df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
-            df = df.drop_duplicates(["geometry"])
-            df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
-            pdf = gpd.overlay(gdf, df, how = 'union')
-            check_topology(pdf)
-            self.geosolution = pdf
-        elif 0.0 < self.area_threshold <= 0.8:
-            area_thres = (spacing*spacing)*self.area_threshold
-            hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
-            df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
-            df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
-            df = df.drop_duplicates(["geometry"])
-            df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
-            pdf = gpd.overlay(gdf, df, how = 'union')
-            check_topology(pdf)
-            self.geosolution = pdf
+        if hexagon_dis:
+            self.geosolution = final_hexa
         else:
-            raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
+            if self.area_threshold == None:
+                area_thres = (spacing*spacing)*0.33
+                hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
+                df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
+                df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
+                df = df.drop_duplicates(["geometry"])
+                df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
+                pdf = gpd.overlay(gdf, df, how = 'union')
+                check_topology(pdf)
+                self.geosolution = pdf
+            elif 0.0 < self.area_threshold <= 0.8:
+                area_thres = (spacing*spacing)*self.area_threshold
+                hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
+                df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
+                df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
+                df = df.drop_duplicates(["geometry"])
+                df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
+                pdf = gpd.overlay(gdf, df, how = 'union')
+                check_topology(pdf)
+                self.geosolution = pdf
+            else:
+                raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
 
 
 class merge_shapefile:
